Package: autonomics
Type: Package
Title: Unified Statistical Modeling of Omics Data
Version: 1.20.0
Authors@R: c(person('Aditya',   'Bhagwat',      email = 'aditya.bhagwat@uni-marburg.de',    role = c('aut', 'cre')), 
             person('Richard',  'Cotton',       email = 'richierocks@gmail.com',            role = c('aut')),
             person('Vanessa',  'Beutgen',      email = 'vanessa.beutgen@uni-marburg.de',   role = c('ctb')),
             person('Witold',   'Szymanski',    email = 'witold.szymanski@uni-marburg.de',  role = c('ctb')),
             person('Shahina',  'Hayat',        email = 'shahina.hayat@hotmail.com',        role = c('ctb')),
             person('Laure',    'Cougnaud',     email = 'laure.cougnaud@openanalytics.eu',  role = c('ctb')), 
             person('Hinrich',  'Goehlmann',    email = 'hinrich@goehlmann.info',           role = c('sad')),
             person('Karsten',  'Suhre',        email = 'kas2049@qatar-med.cornell.edu',    role = c('sad')), 
             person('Johannes', 'Graumann',     email = 'johannes.graumann@uni-marburg.de', role = c('aut', 'sad'))
             )
Description: This package unifies access to Statistal Modeling of Omics
        Data. Across linear modeling engines (lm, lme, lmer, limma, and
        wilcoxon). Across coding systems (treatment, difference,
        deviation, etc). Across model formulae (with/without intercept,
        random effect, interaction or nesting). Across omics platforms
        (microarray, rnaseq, msproteomics, affinity proteomics,
        metabolomics). Across projection methods (pca, pls, sma, lda,
        spls, opls). Across clustering methods (hclust, pam, cmeans).
        Across survival methods (coxph, survdiff, coin). It provides a
        fast enrichment analysis implementation.
License: GPL-3
Encoding: UTF-8
VignetteBuilder: knitr
biocViews: Software, DataImport, Preprocessing, DimensionReduction,
        PrincipalComponent, Regression, DifferentialExpression,
        GeneSetEnrichment, Transcriptomics, Transcription,
        GeneExpression, RNASeq, Microarray, Proteomics, Metabolomics,
        MassSpectrometry,
BugReports: https://gitlab.uni-marburg.de/fb20/ag-graumann/software/autonomics/issues
RoxygenNote: 7.3.3
Depends: R (>= 4.0)
Imports: abind, arrow, BiocFileCache, BiocGenerics, bit64, cluster,
        codingMatrices, colorspace, data.table, dplyr, edgeR, ggforce,
        ggplot2, ggrepel, graphics, grDevices, grid, gridExtra, limma,
        lme4, magrittr, matrixStats, methods, MultiAssayExperiment,
        parallel, RColorBrewer, rlang, R.utils, readxl, S4Vectors,
        scales, stats, stringi, SummarizedExperiment, survival, tidyr,
        tidyselect, tools, utils, vsn
Suggests: affy, AnnotationDbi, AnnotationHub, apcluster, Biobase,
        BiocManager, BiocStyle, Biostrings, coin, diagram, DBI, e1071,
        ensembldb, GenomicDataCommons, GenomicRanges, GEOquery,
        ggstance, ggridges, ggtext, hgu95av2.db, ICSNP, jsonlite,
        knitr, lmerTest, MASS, mclust, mixOmics, mixtools, mpm, nlme,
        OlinkAnalyze, org.Hs.eg.db, org.Mm.eg.db, patchwork,
        pcaMethods, pheatmap, progeny, propagate, RCurl, RSQLite,
        remotes, rmarkdown, ropls, Rsubread, readODS, rtracklayer,
        statmod, testthat, UniProt.ws, writexl, XML
Config/pak/sysreqs: cmake libfontconfig1-dev libfreetype6-dev make
        libicu-dev libssl-dev zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:55:12 UTC
RemoteUrl: https://github.com/bioc/autonomics
RemoteRef: RELEASE_3_23
RemoteSha: 1a54a8c243c9f20b4f5650b57d6e211f4cad5b97
NeedsCompilation: no
Packaged: 2026-05-03 16:23:11 UTC; root
Author: Aditya Bhagwat [aut, cre],
  Richard Cotton [aut],
  Vanessa Beutgen [ctb],
  Witold Szymanski [ctb],
  Shahina Hayat [ctb],
  Laure Cougnaud [ctb],
  Hinrich Goehlmann [sad],
  Karsten Suhre [sad],
  Johannes Graumann [aut, sad]
Maintainer: Aditya Bhagwat <aditya.bhagwat@uni-marburg.de>
Built: R 4.6.0; ; 2026-05-03 17:20:53 UTC; unix
