# Generated by roxygen2: do not edit by hand

S3method(abstractvar,SummarizedExperiment)
S3method(abstractvar,data.table)
S3method(abstractvec,SummarizedExperiment)
S3method(abstractvec,data.table)
S3method(add_adjusted_pvalues,"NULL")
S3method(add_adjusted_pvalues,SummarizedExperiment)
S3method(add_adjusted_pvalues,data.table)
S3method(bin,SummarizedExperiment)
S3method(bin,character)
S3method(bin,factor)
S3method(bin,logical)
S3method(bin,matrix)
S3method(bin,numeric)
S3method(block2limma,"NULL")
S3method(block2limma,character)
S3method(block2limma,formula)
S3method(block2limma,list)
S3method(block2lm,"NULL")
S3method(block2lm,character)
S3method(block2lm,formula)
S3method(block2lm,list)
S3method(block2lme,character)
S3method(block2lme,formula)
S3method(block2lme,list)
S3method(block2lmer,character)
S3method(block2lmer,formula)
S3method(block2lmer,list)
S3method(code,character)
S3method(code,data.table)
S3method(code,factor)
S3method(code,logical)
S3method(code,numeric)
S3method(coefs,"NULL")
S3method(coefs,SummarizedExperiment)
S3method(coefs,data.table)
S3method(coefs,factor)
S3method(collapse_in,character)
S3method(collapse_in,factor)
S3method(collapse_in,list)
S3method(count_in,character)
S3method(count_in,factor)
S3method(count_in,list)
S3method(count_out,character)
S3method(count_out,factor)
S3method(count_out,list)
S3method(create_design,SummarizedExperiment)
S3method(create_design,data.table)
S3method(extract_rectangle,character)
S3method(extract_rectangle,data.table)
S3method(extract_rectangle,matrix)
S3method(factorize,SummarizedExperiment)
S3method(factorize,character)
S3method(factorize,factor)
S3method(factorize,logical)
S3method(factorize,matrix)
S3method(factorize,numeric)
S3method(fits,"NULL")
S3method(fits,SummarizedExperiment)
S3method(fits,data.table)
S3method(group_by_level,character)
S3method(group_by_level,data.table)
S3method(group_by_level,factor)
S3method(guess_fitsep,SummarizedExperiment)
S3method(guess_fitsep,data.table)
S3method(guess_sep,SummarizedExperiment)
S3method(guess_sep,character)
S3method(guess_sep,factor)
S3method(guess_sep,numeric)
S3method(has_multiple_levels,SummarizedExperiment)
S3method(has_multiple_levels,character)
S3method(has_multiple_levels,data.table)
S3method(has_multiple_levels,factor)
S3method(has_multiple_levels,numeric)
S3method(impute,SummarizedExperiment)
S3method(impute,matrix)
S3method(impute,numeric)
S3method(modeldt,"NULL")
S3method(modeldt,SummarizedExperiment)
S3method(modeldt,data.table)
S3method(modelfeatures,SummarizedExperiment)
S3method(modelfeatures,data.table)
S3method(modelvar,"NULL")
S3method(modelvar,SummarizedExperiment)
S3method(modelvar,data.table)
S3method(modelvec,SummarizedExperiment)
S3method(modelvec,data.table)
S3method(summarize_fit,SummarizedExperiment)
S3method(summarize_fit,data.table)
S3method(varlevels_dont_clash,SummarizedExperiment)
S3method(varlevels_dont_clash,data.table)
export("%<>%")
export("%>%")
export("analysis<-")
export("counts<-")
export("cpm<-")
export("fdata<-")
export("fdt<-")
export("fnames<-")
export("fvars<-")
export("is_imputed<-")
export("log2counts<-")
export("log2cpm<-")
export("log2diffs<-")
export("log2proteins<-")
export("log2sites<-")
export("log2tpm<-")
export("sdata<-")
export("sdt<-")
export("snames<-")
export("svalues<-")
export("svars<-")
export("tpm<-")
export("values<-")
export("weights<-")
export(.coxph)
export(.densities)
export(.extract_effectsize_features)
export(.extract_fdr_features)
export(.extract_n_features)
export(.extract_p_features)
export(.fit_survival)
export(.logrank)
export(.merge)
export(.read_compounddiscoverer)
export(.read_diann_precursors)
export(.read_diann_proteingroups)
export(.read_maxquant_phosphosites)
export(.read_maxquant_proteingroups)
export(.read_metabolon)
export(.read_rectangles)
export(.read_rnaseq_bams)
export(.read_rnaseq_counts)
export(.read_somascan)
export(.survdiff)
export(ABBREV_TO_ORGNAME)
export(AUTONOMICS_DATASETS)
export(COMPOUNDDISCOVERER_PATTERNS)
export(DATADIR)
export(DIMREDENGINES)
export(DIMREDSUPER)
export(DIMREDUN)
export(EXISTENCE_TO_NUMBER)
export(LINMOD)
export(LINMODENGINES)
export(MAXQUANT_PATTERNS)
export(MSIGCOLLECTIONSHUMAN)
export(MSIGCOLLECTIONSMOUSE)
export(MSIGDIR)
export(OPENTARGETSDIR)
export(PRECURSOR_QUANTITY)
export(REVIEWED_TO_NUMBER)
export(TAXON_TO_ORGNAME)
export(TESTS)
export(TRANSFORMENGINES)
export(TRANSFORMSTRICT)
export(X)
export(abind)
export(abstract_fit)
export(abstractvar)
export(abstractvec)
export(add_adjusted_pvalues)
export(add_assay_means)
export(add_facetvars)
export(add_opentargets_by_uniprot)
export(add_psp)
export(add_smiles)
export(all_non_numeric)
export(altenrich)
export(analysis)
export(analyze)
export(annotate_compounddiscoverer)
export(annotate_maxquant)
export(annotate_uniprot_rest)
export(assert_character_matrix)
export(assert_compounddiscoverer_output)
export(assert_correlation_matrix)
export(assert_diann_report)
export(assert_fastadt)
export(assert_fragpipe_tsv)
export(assert_is_fraction)
export(assert_is_valid_sumexp)
export(assert_maxquant_phosphosites)
export(assert_maxquant_proteingroups)
export(assert_positive_number)
export(assert_scalar_subset)
export(assert_valid_formula)
export(assert_weakly_positive_number)
export(awblinmod)
export(awblinmod_limma)
export(awblinmod_lm)
export(awblinmod_lme)
export(awblinmod_lmer)
export(beta)
export(bin)
export(bin_assay)
export(biplot)
export(biplot_corrections)
export(biplot_covariates)
export(biplot_transforms)
export(biplot_transforms_assays)
export(block2limma)
export(block2lm)
export(block2lme)
export(block2lmer)
export(block_has_two_levels)
export(cbind_imputed)
export(center)
export(center_mean)
export(center_median)
export(code)
export(code_control)
export(code_deviation)
export(code_deviation_first)
export(code_diff)
export(code_diff_forward)
export(code_helmert)
export(code_helmert_forward)
export(coefs)
export(coefs_estimable)
export(collapse_in)
export(collapsed_entrezg_to_symbol)
export(contr.diff)
export(contr.treatment.explicit)
export(contrast_coefs)
export(contrast_subgroup_cols)
export(contrast_subgroup_rows)
export(contrastdt)
export(count_in)
export(count_out)
export(counts)
export(counts2cpm)
export(counts2tpm)
export(cpm)
export(cpm2counts)
export(create_design)
export(data.table)
export(default_formula)
export(default_geom)
export(default_sfile)
export(defaultmsigfile)
export(demultiplex)
export(densities)
export(dequantify)
export(dequantify_compounddiscoverer)
export(downfeatures)
export(download_data)
export(download_gtf)
export(download_mcclain21)
export(dt2mat)
export(effectdt)
export(effectmat)
export(effectsizemat)
export(effectvar)
export(effectvec)
export(enrichment)
export(ens2org)
export(entrezg_to_symbol)
export(exp2transform)
export(extract)
export(extract_contrast_features)
export(extract_rectangle)
export(factor.vars)
export(factor2logical)
export(factorize)
export(factorize_assay)
export(fbind)
export(fcluster)
export(fcor)
export(fdata)
export(fdist)
export(fdr2p)
export(fdrmat)
export(fdrvar)
export(fdrvec)
export(fdt)
export(filter_exprs_replicated_in_some_subgroup)
export(filter_features)
export(filter_medoid)
export(filter_samples)
export(fit_limma)
export(fit_lm)
export(fit_lme)
export(fit_lmer)
export(fit_survival)
export(fit_wilcoxon)
export(fitcoefs)
export(fits)
export(fix_xlgenes)
export(flevels)
export(fnames)
export(formula2str)
export(fscale)
export(ftype)
export(fvalues)
export(fvars)
export(genome_to_orgdb)
export(group_by_level)
export(guess_compounddiscoverer_quantity)
export(guess_fitsep)
export(guess_maxquant_quantity)
export(guess_sep)
export(has_multiple_levels)
export(hdlproteins)
export(impute)
export(inf_to_na)
export(installed)
export(invert_subgroups)
export(invnorm)
export(is_character_matrix)
export(is_collapsed_subset)
export(is_compounddiscoverer_output)
export(is_correlation_matrix)
export(is_diann_report)
export(is_fastadt)
export(is_file)
export(is_fraction)
export(is_fragpipe_tsv)
export(is_imputed)
export(is_maxquant_phosphosites)
export(is_maxquant_proteingroups)
export(is_non_numeric)
export(is_positive_number)
export(is_scalar_subset)
export(is_sig)
export(is_valid_formula)
export(is_weakly_positive_number)
export(keep_estimable_features)
export(label2index)
export(lda)
export(left.vars)
export(linmod_limma)
export(linmod_lm)
export(linmod_lme)
export(linmod_lmer)
export(linmod_wilcoxon)
export(list2mat)
export(list_files)
export(loadingmat)
export(loadings)
export(log2counts)
export(log2cpm)
export(log2diffs)
export(log2proteins)
export(log2sites)
export(log2tpm)
export(log2transform)
export(logical2factor)
export(make_alpha_palette)
export(make_colors)
export(make_volcano_dt)
export(map_fvalues)
export(mat2dt)
export(matrix2sumexp)
export(mclust_breaks)
export(mclust_parameters)
export(mdsplot)
export(merge_compounddiscoverer)
export(merge_fdata)
export(merge_fdt)
export(merge_ffile)
export(merge_sample_excel)
export(merge_sample_file)
export(merge_sdata)
export(merge_sdt)
export(message_df)
export(minusinf_to_na)
export(mixtools_breaks)
export(mixtools_parameters)
export(model_coefs)
export(modeldt)
export(modelfeatures)
export(modelmat)
export(modelvar)
export(modelvec)
export(na_to_string)
export(na_to_zero)
export(nan_to_na)
export(nfactors)
export(no_nas)
export(object1)
export(object2)
export(opls)
export(order_on_effect)
export(order_on_p)
export(order_on_t)
export(overall_parameters)
export(parse_maxquant_hdrs)
export(pca)
export(pdt)
export(pg_to_canonical)
export(pg_to_isoforms)
export(plot_coef_densities)
export(plot_contrast_venn)
export(plot_contrastogram)
export(plot_data)
export(plot_densities)
export(plot_densities_transforms)
export(plot_design)
export(plot_detections)
export(plot_exprs)
export(plot_exprs_per_coef)
export(plot_feature_boxplots)
export(plot_feature_densities)
export(plot_feature_violins)
export(plot_fit_summary)
export(plot_heatmap)
export(plot_matrix)
export(plot_sample_boxplots)
export(plot_sample_densities)
export(plot_sample_nas)
export(plot_sample_violins)
export(plot_subgroup_nas)
export(plot_subgroup_points)
export(plot_subgroup_violins)
export(plot_summarized_detections)
export(plot_summary)
export(plot_survival)
export(plot_venn)
export(plot_venn_heatmap)
export(plot_violins)
export(plot_violins_transforms)
export(plot_volcano)
export(plot_x_density)
export(plot_xy_density)
export(plot_xy_scatter)
export(plot_y_density)
export(pls)
export(pmat)
export(prep_survival)
export(preprocess_rnaseq_counts)
export(pull_columns)
export(pvalues_estimable)
export(pvar)
export(pvec)
export(quantile_breaks)
export(quantnorm)
export(random_nas)
export(read_affymetrix)
export(read_compounddiscoverer)
export(read_contaminantdt)
export(read_diann)
export(read_diann_pgmatrix)
export(read_diann_phosphodiffs)
export(read_diann_phosphosites)
export(read_diann_proteingroups)
export(read_fragpipe)
export(read_maxquant_phosphosites)
export(read_maxquant_proteingroups)
export(read_metabolon)
export(read_msigdt)
export(read_olink)
export(read_phosphosites)
export(read_proteingroups)
export(read_rectangles)
export(read_rnaseq_bams)
export(read_rnaseq_counts)
export(read_salmon)
export(read_somascan)
export(read_uniprotdt)
export(recollapse)
export(reset_fit)
export(right.vars)
export(rm_diann_contaminants)
export(rm_missing_in_all_samples)
export(rm_missing_in_some_samples)
export(rm_singleton_samples)
export(rm_unmatched_samples)
export(sampleid_values)
export(sbind)
export(scaledlibsizes)
export(scor)
export(scoremat)
export(scores)
export(sdata)
export(sdist)
export(sdt)
export(slevels)
export(sma)
export(snames)
export(split_extract)
export(split_extract_fixed)
export(split_extract_regex)
export(split_features)
export(split_samples)
export(spls)
export(sscale)
export(stepauc)
export(stri_any_regex)
export(stri_detect_fixed_in_collapsed)
export(subgroup_array)
export(subgroup_levels)
export(subgroup_matrix)
export(subgroup_values)
export(subtract_baseline)
export(subtract_differences)
export(subtract_pairs)
export(sumexp_to_groupdt)
export(sumexp_to_longdt)
export(sumexp_to_tsv)
export(sumexp_to_widedt)
export(sumexplist_to_longdt)
export(summarize_fit)
export(survobj)
export(svalues)
export(svars)
export(systematic_nas)
export(tag_features)
export(tag_hdlproteins)
export(taxon2org)
export(tdt)
export(tmat)
export(tpm)
export(tvar)
export(tvec)
export(twofactor_sumexp)
export(uncollapse)
export(upfeatures)
export(values)
export(varlevels_dont_clash)
export(venn_detects)
export(vsn)
export(weights)
export(write_ods)
export(write_xl)
export(zero_to_na)
export(zscore)
exportMethods(analysis)
exportMethods(factor.vars)
import(ggplot2)
import(stringi)
importFrom(BiocFileCache,BiocFileCache)
importFrom(BiocFileCache,bfcadd)
importFrom(BiocFileCache,bfcquery)
importFrom(BiocFileCache,bfcrpath)
importFrom(BiocGenerics,cbind)
importFrom(MultiAssayExperiment,"colData<-")
importFrom(MultiAssayExperiment,"experiments<-")
importFrom(MultiAssayExperiment,MultiAssayExperiment)
importFrom(MultiAssayExperiment,colData)
importFrom(MultiAssayExperiment,experiments)
importFrom(R.utils,gunzip)
importFrom(RColorBrewer,brewer.pal)
importFrom(S4Vectors,"metadata<-")
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,metadata)
importFrom(SummarizedExperiment,"assayNames<-")
importFrom(SummarizedExperiment,"assays<-")
importFrom(SummarizedExperiment,"colData<-")
importFrom(SummarizedExperiment,"rowData<-")
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(SummarizedExperiment,assayNames)
importFrom(SummarizedExperiment,assays)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,makeSummarizedExperimentFromExpressionSet)
importFrom(SummarizedExperiment,rowData)
importFrom(abind,adrop)
importFrom(arrow,read_parquet)
importFrom(cluster,pam)
importFrom(cluster,silhouette)
importFrom(codingMatrices,code_control)
importFrom(codingMatrices,code_deviation)
importFrom(codingMatrices,code_diff)
importFrom(codingMatrices,code_helmert)
importFrom(codingMatrices,contr.diff)
importFrom(colorspace,sequential_hcl)
importFrom(data.table,":=")
importFrom(data.table,.I)
importFrom(data.table,.N)
importFrom(data.table,.SD)
importFrom(data.table,as.data.table)
importFrom(data.table,copy)
importFrom(data.table,data.table)
importFrom(data.table,dcast)
importFrom(data.table,dcast.data.table)
importFrom(data.table,fcoalesce)
importFrom(data.table,fread)
importFrom(data.table,fwrite)
importFrom(data.table,is.data.table)
importFrom(data.table,melt.data.table)
importFrom(data.table,merge.data.table)
importFrom(data.table,rbindlist)
importFrom(data.table,set)
importFrom(data.table,setkeyv)
importFrom(data.table,setnames)
importFrom(data.table,setorderv)
importFrom(data.table,tstrsplit)
importFrom(edgeR,filterByExpr)
importFrom(ggforce,facet_wrap_paginate)
importFrom(ggrepel,geom_label_repel)
importFrom(ggrepel,geom_text_repel)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,hcl)
importFrom(grDevices,pdf)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,image)
importFrom(graphics,layout)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,pie)
importFrom(graphics,polygon)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(grid,grid.draw)
importFrom(grid,grid.layout)
importFrom(grid,grid.newpage)
importFrom(gridExtra,arrangeGrob)
importFrom(gridExtra,grid.arrange)
importFrom(limma,contrasts.fit)
importFrom(limma,duplicateCorrelation)
importFrom(limma,eBayes)
importFrom(limma,lmFit)
importFrom(limma,makeContrasts)
importFrom(limma,removeBatchEffect)
importFrom(limma,vennDiagram)
importFrom(limma,voom)
importFrom(magrittr,"%<>%")
importFrom(magrittr,"%>%")
importFrom(magrittr,add)
importFrom(magrittr,and)
importFrom(magrittr,divide_by)
importFrom(magrittr,equals)
importFrom(magrittr,extract)
importFrom(magrittr,extract2)
importFrom(magrittr,is_in)
importFrom(magrittr,multiply_by)
importFrom(magrittr,or)
importFrom(magrittr,set_colnames)
importFrom(magrittr,set_names)
importFrom(magrittr,set_rownames)
importFrom(magrittr,subtract)
importFrom(matrixStats,colAnys)
importFrom(matrixStats,colWeightedMeans)
importFrom(matrixStats,rowAlls)
importFrom(matrixStats,rowAnys)
importFrom(matrixStats,rowMaxs)
importFrom(matrixStats,rowMins)
importFrom(matrixStats,rowSds)
importFrom(matrixStats,rowVars)
importFrom(methods,as)
importFrom(methods,is)
importFrom(parallel,detectCores)
importFrom(readxl,excel_sheets)
importFrom(readxl,read_excel)
importFrom(rlang,as_name)
importFrom(rlang,as_string)
importFrom(rlang,enexpr)
importFrom(rlang,enquo)
importFrom(rlang,eval_tidy)
importFrom(rlang,expr_text)
importFrom(rlang,quo_is_null)
importFrom(rlang,quo_name)
importFrom(stats,"contrasts<-")
importFrom(stats,IQR)
importFrom(stats,aggregate)
importFrom(stats,approxfun)
importFrom(stats,as.dist)
importFrom(stats,as.formula)
importFrom(stats,contr.sum)
importFrom(stats,contr.treatment)
importFrom(stats,contrasts)
importFrom(stats,cor)
importFrom(stats,cutree)
importFrom(stats,density)
importFrom(stats,dist)
importFrom(stats,dnorm)
importFrom(stats,hclust)
importFrom(stats,lm)
importFrom(stats,lowess)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.exclude)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,phyper)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,wilcox.test)
importFrom(survival,Surv)
importFrom(survival,coxph)
importFrom(survival,survdiff)
importFrom(survival,survfit)
importFrom(tidyr,separate_rows)
importFrom(tools,R_user_dir)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,adist)
importFrom(utils,capture.output)
importFrom(utils,count.fields)
importFrom(utils,download.file)
importFrom(utils,getFromNamespace)
importFrom(utils,installed.packages)
importFrom(utils,unzip)
